@@ -561,7 +561,7 @@ class SensitiveDetector:
             "foo bar",
             "test user",
             "c:\\temp\\",
-            "/tmp/",
+            "/tmp/",  # nosec B108
             "example.txt",
             "test.py",
             "function_name",
@@ -812,7 +812,7 @@ class SensitiveDetector:
         # Sort by start position
         matches.sort(key=lambda x: x.start)
 
-        result = []
+        result: List[SensitiveMatch] = []
         for current_match in matches:
             # Check for overlap with existing matches
             has_overlap = False
