@@ -25,7 +25,7 @@ class MaskingMetadata:
         self.mask_id = mask_id
         self.created_at = datetime.now().isoformat()
         self.matches: List[Dict[str, Any]] = []
-        self.file_hash = None
+        self.file_hash: Optional[str] = None
 
     def to_dict(self) -> Dict[str, Any]:
         """Convert metadata to dictionary."""
@@ -263,7 +263,7 @@ class SensitiveMasker:
         with open(metadata_file, "w", encoding="utf-8") as f:
             json.dump(metadata.to_dict(), f, indent=2, ensure_ascii=False)
 
-        return metadata
+        return metadata  # type: ignore[no-any-return]
 
     def restore_text(
         self, masked_text: str, metadata: MaskingMetadata, show_changes: bool = False
@@ -558,7 +558,7 @@ class SensitiveMasker:
         print()
 
         # Group matches by pattern
-        pattern_counts = {}
+        pattern_counts: Dict[str, int] = {}
         for match in matches:
             pattern = match.pattern_name
             pattern_counts[pattern] = pattern_counts.get(pattern, 0) + 1
@@ -594,7 +594,7 @@ class SensitiveMasker:
         print()
 
         # Group matches by pattern
-        pattern_counts = {}
+        pattern_counts: Dict[str, int] = {}
         for match in matches:
             pattern = match["pattern_name"]
             pattern_counts[pattern] = pattern_counts.get(pattern, 0) + 1
@@ -627,7 +627,7 @@ class SensitiveMasker:
         print()
 
         # Group matches by pattern
-        pattern_counts = {}
+        pattern_counts: Dict[str, int] = {}
         for match in matches:
             pattern = match["pattern_name"]
             pattern_counts[pattern] = pattern_counts.get(pattern, 0) + 1
@@ -650,7 +650,7 @@ class SensitiveMasker:
         Returns:
             Dictionary with statistics
         """
-        pattern_counts = {}
+        pattern_counts: Dict[str, int] = {}
         total_matches = len(metadata.matches)
         total_chars_masked = 0
 
